@@ -1,5 +1,6 @@
 from .main import EaseMySQL, SQLStatement, SQLSession, SQLSessionContract
 from .utils import where_in, where_simple, where_complex
+from .ListORM import ListORM
 
 """
 pip install pymysql --upgrade
@@ -15,9 +16,10 @@ select * from test where nickname like "%风行水上%"
     传入的参数以列表或字典形式提供给 cursor.execute() 方法
 """
 
-VERSION = '1.0.8'
+VERSION = '1.1.1'
 
 __all__ = [
+    "VERSION",
     "EaseMySQL",
     "SQLStatement",
     "SQLSession",
@@ -25,4 +27,5 @@ __all__ = [
     "where_in",
     "where_simple",
     "where_complex",
+    "ListORM",
 ]
